# Generated by Django 3.2.7 on 2021-11-27 09:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_pay2', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='payment',
            name='payment_system',
            field=models.CharField(default='qiwi_kassa', max_length=50, verbose_name='Код платежной системы'),
            preserve_default=False,
        ),
    ]
